Spaste
=========

The official client for `spaste.io <https://spaste.io>`__.

Installation
------------

It's recommended that you use Python 3.

You can install Spaste from
`PyPI <https://pypi.org/project/spaste/>`__:

.. code:: bash

    pip install spaste

Usage
-----

See the instructions on `spaste.io <https://spaste.io>`__ for more
information about Spaste. For more information on how to use the command
line tool itself, see the built-in help:

.. code:: bash

    spaste --help